#####################
Search and django CMS
#####################

For powerful full-text search within the django CMS, we suggest using
`Haystack`_ together with `aldryn-search`_.

.. _Haystack: http://haystacksearch.org/
.. _aldryn-search: https://github.com/aldryn/aldryn-search
